
/*
A simple C++ wrapper around WIN32 window handle
Copyright (C) 2000 Antti Markus (antti@pld.ttu.ee)

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "ttwindow.h"

void Reverse(char* pStr)
{
  int nLen=0;
  while(*(pStr+nLen))
    nLen++;
  int j=nLen-1;
  for(int i=0; i < j; i++, j--)
  {
    //swap *(pStr+i) and *(pStr+j)
    *(pStr+i)^=*(pStr+j);
    *(pStr+j)^=*(pStr+i);
    *(pStr+i)^=*(pStr+j);
  }
}

int itoa(int n, char* pStr)
{
  int sign=n;
  if(sign < 0)
    n=-n;
  int i=0;
  do
  {
    *(pStr+i++)=n%10+'0';
  }
  while((n/=10) > 0);
  if(sign < 0)
    *(pStr+i++)='-';
  *(pStr+i)='\0';
  Reverse(pStr);
  return i;
}

TTWindow::TTWindow(const HWND hNewHandle)
{
  hWnd=hNewHandle;
}

TTWindow::~TTWindow(void)
{
}

int TTWindow::GetTextLen(void) const
{
  return SendMessage(hWnd,
                     WM_GETTEXTLENGTH,
                     (WPARAM)0,
                     (LPARAM)0);
}

void TTWindow::GetText(char* ptrText) const
{
  SendMessage(hWnd,
              WM_GETTEXT,
              (WPARAM)GetTextLen()+1,
              (LPARAM)ptrText);
}

void TTWindow::SetText(const char* ptrNewText)
{
  lResult=SendMessage(hWnd, WM_SETTEXT, 
                      (WPARAM)0, 
                      (LPARAM)(LPCTSTR)ptrNewText);
}

void TTWindow::SetText(const int iNumber)
{
  char* ptrText=new char[10];
  int nLen=itoa(iNumber, ptrText);
  lResult=SendMessage(hWnd, WM_SETTEXT, 
                      (WPARAM)0, 
                      (LPARAM)(LPCTSTR)ptrText);
  delete [] ptrText;
  ptrText=0;
}

void TTWindow::Show(void)
{
  lResult=ShowWindow(hWnd, SW_SHOW);
}

HDWP TTWindow::DeferShow(HDWP hdwp)
{
  return DeferWindowPos(hdwp, hWnd, 0, 0, 0, 0, 0, 
                        SWP_NOACTIVATE | SWP_NOZORDER | SWP_NOMOVE | SWP_NOSIZE | SWP_SHOWWINDOW);
}

void TTWindow::Hide(void)
{
  lResult=ShowWindow(hWnd, SW_HIDE);
}                                 

HDWP TTWindow::DeferHide(HDWP hdwp)
{
  return DeferWindowPos(hdwp, hWnd, 0, 0, 0, 0, 0, 
                        SWP_NOACTIVATE | SWP_NOZORDER | SWP_NOMOVE | SWP_NOSIZE | SWP_HIDEWINDOW);
}

void TTWindow::Enable(void)
{
  lResult=EnableWindow(hWnd, TRUE);
}

void TTWindow::Disable(void)
{
  lResult=(LRESULT)EnableWindow(hWnd, FALSE);
}

BOOL TTWindow::Visible(void)
{
  return IsWindowVisible(hWnd);
}

HDWP TTWindow::DeferMove(HDWP hdwp, const int x, const int y)
{
  return DeferWindowPos(hdwp, hWnd, 0, x, y, 0, 0,
                        SWP_NOACTIVATE | SWP_NOZORDER | SWP_NOSIZE);
}

HDWP TTWindow::DeferSize(HDWP hdwp, const int w, const int h)
{                                                                   
  return DeferWindowPos(hdwp, hWnd, 0, 0, 0, w, h,
                        SWP_NOACTIVATE | SWP_NOZORDER | SWP_NOMOVE);
}

HDWP TTWindow::DeferMoveSize(HDWP hdwp, const int x, const int y, const int w, const int h)
{                                                
  return DeferWindowPos(hdwp, hWnd, 0, x, y, w, h,
                        SWP_NOACTIVATE | SWP_NOZORDER);
}

void TTWindow::GetClientRect(RECT& r)
{              
  ::GetClientRect(hWnd, &r);
}

void TTWindow::GetRect(RECT& r)
{                            
  GetWindowRect(hWnd, &r);
}

void TTWindow::GetPlacement(WINDOWPLACEMENT& placement)
{                     
  placement.length=sizeof(WINDOWPLACEMENT);
  GetWindowPlacement(hWnd, &placement);
}


