
/*
A simple C++ wrapper around WIN32 window handle
Copyright (C) 2000 Antti Markus (antti@pld.ttu.ee)

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef ttwindowH
#define ttwindowH

#ifndef STRICT
#define STRICT
#endif

#ifndef WIN32_LEAN_AND_MEAN
#define WIN32_LEAN_AND_MEAN
#endif

#include <windows.h>

class TTWindow
{
private:
  HWND hWnd;
protected:
  LRESULT lResult;
public:
  TTWindow(void);
  TTWindow(const HWND hNewHandle);
  ~TTWindow(void);
  HWND GetHandle(void);
  LRESULT GetResult(void) const;
  void SetText(const char* ptrNewText);
  void SetText(const int iNumber);
  void GetText(char* ptrText) const;
  int GetTextLen(void) const;
  void Show(void);
  HDWP DeferShow(HDWP hdwp);
  void Hide(void);          
  HDWP DeferHide(HDWP hdwp);
  void Enable(void);
  void Disable(void);
  BOOL Visible(void);
  HDWP DeferMove(HDWP hdwp, const int x, const int y);
  HDWP DeferSize(HDWP hdwp, const int w, const int h);
  HDWP DeferMoveSize(HDWP hdwp, const int x, const int y, const int w, const int h);
  void GetClientRect(RECT& r);
  void GetRect(RECT& r);
  void GetPlacement(WINDOWPLACEMENT& placement);
};

typedef TTWindow* PTTWindow;

inline TTWindow::TTWindow(void)
{
  hWnd=0;
  lResult=0;
}

inline LRESULT TTWindow::GetResult(void) const
{
  return lResult;
}

inline HWND TTWindow::GetHandle(void)
{
  return hWnd;
}


#endif